BotCommandScopeAllPrivateChats class

Represents the scope of bot commands, covering all private chats.

Inheritance

Constructors

BotCommandScopeAllPrivateChats()
Basic constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Scope type, must be all_private_chats
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited