BotCommandScopeDefault class

Represents the default scope of bot commands. Default commands are used if no commands with a narrower scope are specified for the user.

Inheritance

Constructors

BotCommandScopeDefault()
Basic constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Scope type, must be default
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited