CallbackQuery class

This object represents an incoming callback query from a callback button in an inline keyboard. If the button that originated the query was attached to a message sent by the bot, the field message will be present. If the button was attached to a message sent via the bot (in inline mode), the field inline_message_id will be present. Exactly one of the fields data or game_short_name will be present.

Constructors

CallbackQuery({required String id, required User from, Message? message, String? inlineMessageId, required String chatInstance, String? data, String? gameShortName})
Basic constructor

Properties

chatInstance ↔ String
Global identifier, uniquely corresponding to the chat to which the message with the callback button was sent. Useful for high scores in games.
getter/setter pair
data ↔ String?
Optional. Data associated with the callback button. Be aware that the message originated the query can contain no callback buttons with this data.
getter/setter pair
from ↔ User
Sender
getter/setter pair
gameShortName ↔ String?
Optional. Short name of a Game to be returned, serves as the unique identifier for the game
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
Unique identifier for this query
getter/setter pair
inlineMessageId ↔ String?
Optional. Identifier of the message sent via the bot in inline mode, that originated the query.
getter/setter pair
message ↔ Message?
Optional. Message with the callback button that originated the query. Note that message content and message date will not be available if the message is too old
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → CallbackQuery
Creates a object from a json