ChatMemberUpdated class

This object represents changes in the status of a chat member.

Constructors

ChatMemberUpdated({required Chat chat, required User from, required int date, required ChatMember oldChatMember, required ChatMember newChatMember, ChatInviteLink? inviteLink})
Basic constructor

Properties

chat ↔ Chat
Chat the user belongs to
getter/setter pair
date ↔ int
Date the change was done in Unix time
getter/setter pair
from ↔ User
Performer of the action, which resulted in the change
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Optional. Chat invite link, which was used by the user to join the chat; for joining by invite link events only.
getter/setter pair
newChatMember ↔ ChatMember
New information about the chat member
getter/setter pair
oldChatMember ↔ ChatMember
Previous information about the chat member
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ChatMemberUpdated
Creates a object from a json