File class

This object represents a file ready to be downloaded. The file can be downloaded via the link https://api.telegram.org/file/bot

Constructors

File({required String fileId, required String fileUniqueId, int? fileSize, String? filePath})
Basic constructor

Properties

fileId ↔ String
Identifier for this file, which can be used to download or reuse the file
getter/setter pair
filePath ↔ String?
Optional. File path. Use https://api.telegram.org/file/bot
getter/setter pair
fileSize ↔ int?
Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.
getter/setter pair
fileUniqueId ↔ String
Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → File
Creates a object from a json