ForceReply class

Upon receiving a message with this object, Telegram clients will display a reply interface to the user (act as if the user has selected the bot's message and tapped 'Reply'). This can be extremely useful if you want to create user-friendly step-by-step interfaces without having to sacrifice privacy mode.

Inheritance

Constructors

ForceReply({bool forceReply = true, String? inputFieldPlaceholder, bool? selective})
Basic constructor

Properties

forceReply ↔ bool
Shows reply interface to the user, as if they manually selected the bot's message and tapped 'Reply'
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputFieldPlaceholder ↔ String?
Optional. The placeholder to be shown in the input field when the reply is active; 1-64 characters
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selective ↔ bool?
Optional. Use this parameter if you want to force reply from specific users only. Targets:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ForceReply
Creates a object from a json