InlineQueryResultArticle class

Represents a link to an article or web page.

Inheritance

Constructors

InlineQueryResultArticle({required String id, required String title, required InputMessageContent inputMessageContent, InlineKeyboardMarkup? replyMarkup, String? url, bool? hideUrl, String? description, String? thumbUrl, int? thumbWidth, int? thumbHeight})
Basic constructor

Properties

description ↔ String?
Optional. Short description of the result
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hideUrl ↔ bool?
Optional. Pass True if you don't want the URL to be shown in the message
getter/setter pair
id ↔ String
Unique identifier for this result, 1-64 Bytes
getter/setter pair
inputMessageContent ↔ InputMessageContent
Content of the message to be sent
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
Optional. Inline keyboard attached to the message
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbHeight ↔ int?
Optional. Thumbnail height
getter/setter pair
thumbUrl ↔ String?
Optional. Url of the thumbnail for the result
getter/setter pair
thumbWidth ↔ int?
Optional. Thumbnail width
getter/setter pair
title ↔ String
Title of the result
getter/setter pair
type ↔ String
Type of the result, must be article
getter/setter pair
url ↔ String?
Optional. URL of the result
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited