InlineQueryResultContact class

Represents a contact with a phone number. By default, this contact will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the contact.

Inheritance

Constructors

InlineQueryResultContact({required String id, required String phoneNumber, required String firstName, String? lastName, String? vcard, InlineKeyboardMarkup? replyMarkup, InputMessageContent? inputMessageContent, String? thumbUrl, int? thumbWidth, int? thumbHeight})
Basic constructor

Properties

firstName ↔ String
Contact's first name
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
Unique identifier for this result, 1-64 Bytes
getter/setter pair
inputMessageContent ↔ InputMessageContent?
Optional. Content of the message to be sent instead of the contact
getter/setter pair
lastName ↔ String?
Optional. Contact's last name
getter/setter pair
phoneNumber ↔ String
Contact's phone number
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
Optional. Inline keyboard attached to the message
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbHeight ↔ int?
Optional. Thumbnail height
getter/setter pair
thumbUrl ↔ String?
Optional. Url of the thumbnail for the result
getter/setter pair
thumbWidth ↔ int?
Optional. Thumbnail width
getter/setter pair
type ↔ String
Type of the result, must be contact
getter/setter pair
vcard ↔ String?
Optional. Additional data about the contact in the form of a vCard, 0-2048 bytes
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited