InlineQueryResultDocument class

Represents a link to a file. By default, this file will be sent by the user with an optional caption. Alternatively, you can use input_message_content to send a message with the specified content instead of the file. Currently, only .PDF and .ZIP files can be sent using this method.

Inheritance

Constructors

InlineQueryResultDocument({required String id, required String title, String? caption, ParseMode? parseMode, List<MessageEntity>? captionEntities, required String documentUrl, required String mimeType, String? description, InlineKeyboardMarkup? replyMarkup, InputMessageContent? inputMessageContent, String? thumbUrl, int? thumbWidth, int? thumbHeight})
Basic constructor

Properties

caption ↔ String?
Optional. Caption of the document to be sent, 0-1024 characters after entities parsing
getter/setter pair
captionEntities ↔ List<MessageEntity>?
Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
getter/setter pair
description ↔ String?
Optional. Short description of the result
getter/setter pair
documentUrl ↔ String
A valid URL for the file
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
Unique identifier for this result, 1-64 bytes
getter/setter pair
inputMessageContent ↔ InputMessageContent?
Optional. Content of the message to be sent instead of the file
getter/setter pair
mimeType ↔ String
MIME type of the content of the file, either “application/pdf” or “application/zip”
getter/setter pair
parseMode ↔ ParseMode?
Optional. Mode for parsing entities in the document caption.
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
Optional. Inline keyboard attached to the message
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbHeight ↔ int?
Optional. Thumbnail height
getter/setter pair
thumbUrl ↔ String?
Optional. URL of the thumbnail (JPEG only) for the file
getter/setter pair
thumbWidth ↔ int?
Optional. Thumbnail width
getter/setter pair
title ↔ String
Title for the result
getter/setter pair
type ↔ String
Type of the result, must be document
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited