InlineQueryResultPhoto class

Represents a link to a photo. By default, this photo will be sent by the user with optional caption. Alternatively, you can use input_message_content to send a message with the specified content instead of the photo.

Inheritance

Constructors

InlineQueryResultPhoto({required String id, required String photoUrl, required String thumbUrl, int? photoWidth, int? photoHeight, String? title, String? description, String? caption, ParseMode? parseMode, List<MessageEntity>? captionEntities, InlineKeyboardMarkup? replyMarkup, InputMessageContent? inputMessageContent})
Basic constructor

Properties

caption ↔ String?
Optional. Caption of the photo to be sent, 0-1024 characters after entities parsing
getter/setter pair
captionEntities ↔ List<MessageEntity>?
Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
getter/setter pair
description ↔ String?
Optional. Short description of the result
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
Unique identifier for this result, 1-64 bytes
getter/setter pair
inputMessageContent ↔ InputMessageContent?
Optional. Content of the message to be sent instead of the photo
getter/setter pair
parseMode ↔ ParseMode?
Optional. Mode for parsing entities in the photo caption.
getter/setter pair
photoHeight ↔ int?
Optional. Height of the photo
getter/setter pair
photoUrl ↔ String
A valid URL of the photo. Photo must be in JPEG format. Photo size must not exceed 5MB
getter/setter pair
photoWidth ↔ int?
Optional. Width of the photo
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
Optional. Inline keyboard attached to the message
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbUrl ↔ String
URL of the thumbnail for the photo
getter/setter pair
title ↔ String?
Optional. Title for the result
getter/setter pair
type ↔ String
Type of the result, must be photo
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited