InlineQueryResultVideo class

Represents a link to a page containing an embedded video player or a video file. By default, this video file will be sent by the user with an optional caption. Alternatively, you can use input_message_content to send a message with the specified content instead of the video.

Inheritance

Constructors

InlineQueryResultVideo({required String id, required String videoUrl, required String mimeType, required String thumbUrl, required String title, String? caption, ParseMode? parseMode, List<MessageEntity>? captionEntities, int? videoWidth, int? videoHeight, int? videoDuration, String? description, InlineKeyboardMarkup? replyMarkup, InputMessageContent? inputMessageContent})
Basic constructor

Properties

caption ↔ String?
Optional. Caption of the video to be sent, 0-1024 characters after entities parsing
getter/setter pair
captionEntities ↔ List<MessageEntity>?
Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
getter/setter pair
description ↔ String?
Optional. Short description of the result
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
Unique identifier for this result, 1-64 bytes
getter/setter pair
inputMessageContent ↔ InputMessageContent?
Optional. Content of the message to be sent instead of the video. This field is required if InlineQueryResultVideo is used to send an HTML-page as a result (e.g., a YouTube video).
getter/setter pair
mimeType ↔ String
MIME type of the content of the video URL, “text/html” or “video/mp4”
getter/setter pair
parseMode ↔ ParseMode?
Optional. Mode for parsing entities in the video caption.
getter/setter pair
replyMarkup ↔ InlineKeyboardMarkup?
Optional. Inline keyboard attached to the message
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbUrl ↔ String
URL of the thumbnail (JPEG only) for the video
getter/setter pair
title ↔ String
Title for the result
getter/setter pair
type ↔ String
Type of the result, must be video
getter/setter pair
videoDuration ↔ int?
Optional. Video duration in seconds
getter/setter pair
videoHeight ↔ int?
Optional. Video height
getter/setter pair
videoUrl ↔ String
A valid URL for the embedded video player or video file
getter/setter pair
videoWidth ↔ int?
Optional. Video width
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited