InputContactMessageContent class

Represents the content of a contact message to be sent as the result of an inline query.

Inheritance

Constructors

InputContactMessageContent(String phoneNumber, String firstName, {String? lastName, String? vcard})
Basic constructor

Properties

firstName ↔ String
Contact's first name
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastName ↔ String?
Optional. Contact's last name
getter/setter pair
phoneNumber ↔ String
Contact's phone number
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vcard ↔ String?
Optional. Additional data about the contact in the form of a vCard, 0-2048 bytes
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → InputContactMessageContent
Creates a object from a json