InputMediaPhoto class

Represents a photo to be sent.

Inheritance

Constructors

InputMediaPhoto({required String media, String? caption, ParseMode? parseMode, List<MessageEntity>? captionEntities})
Basic constructor

Properties

caption ↔ String?
Optional. Caption of the photo to be sent, 0-1024 characters after entities parsing
getter/setter pair
captionEntities ↔ List<MessageEntity>?
Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
media ↔ String
File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name.
getter/setter pair
parseMode ↔ ParseMode?
Optional. Mode for parsing entities in the photo caption.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
Type of the result, must be photo
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited