MaskPosition class

This object describes the position on faces where a mask should be placed by default.

Constructors

MaskPosition({required String point, required double xShift, required double yShift, required double scale})
Basic constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
point ↔ String
The part of the face relative to which the mask should be placed. One of “forehead”, “eyes”, “mouth”, or “chin”.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ double
Mask scaling coefficient. For example, 2.0 means double size.
getter/setter pair
xShift ↔ double
Shift by X-axis measured in widths of the mask scaled to the face size, from left to right. For example, choosing -1.0 will place mask just to the left of the default mask position.
getter/setter pair
yShift ↔ double
Shift by Y-axis measured in heights of the mask scaled to the face size, from top to bottom. For example, 1.0 will place the mask just below the default mask position.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → MaskPosition
Creates a object from a json
listFromJsonArray(List json) → List<MaskPosition>
Creates a list of object from a json array