MessageId class

This object represents a unique message identifier.

Constructors

MessageId({required int messageId})
Basic constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageId ↔ int
Unique message identifier
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → MessageId
Creates a object from a json