PollOption class

This object contains information about one answer option in a poll.

Constructors

PollOption({required String text, required int voterCount})
Basic constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
Option text, 1-100 characters
getter/setter pair
voterCount ↔ int
Number of users that voted for this option
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → PollOption
Creates a object from a json
listFromJsonArray(List json) → List<PollOption>
Creates a list of object from a json array