PreCheckoutQuery class

This object contains information about an incoming pre-checkout query.

Constructors

PreCheckoutQuery({required String id, required User from, required String currency, required int totalAmount, required String invoicePayload, String? shippingOptionId, OrderInfo? orderInfo})
Basic constructor

Properties

currency ↔ String
Three-letter ISO 4217 currency code
getter/setter pair
from ↔ User
User who sent the query
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
Unique query identifier
getter/setter pair
invoicePayload ↔ String
Bot specified invoice payload
getter/setter pair
orderInfo ↔ OrderInfo?
Optional. Order information provided by the user
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingOptionId ↔ String?
Optional. Identifier of the shipping option chosen by the user
getter/setter pair
totalAmount ↔ int
Total price in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → PreCheckoutQuery
Creates a object from a json