SentWebAppMessage class

Describes an inline message sent by a Web App on behalf of a user.

Constructors

SentWebAppMessage(String? inlineMessageId)
Basic constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
inlineMessageId ↔ String?
Optional. Identifier of the sent inline message. Available only if there is an inline keyboard attached to the message.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → SentWebAppMessage
Creates a object from a json