UpdateType class

UpdateType for GetUpdates

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

all → List<UpdateType>
Get a list with all UpdateType
no setter

Static Methods

allBut(Iterable<UpdateType> exclusions) → List<UpdateType>
Get a list with allBut UpdateType
forValue(String value) → UpdateType
Get the object from string

Constants

callbackQuery → const UpdateType
CallbackQuery
channelPost → const UpdateType
ChannelPost
chatJoinRequest → const UpdateType
ChatJoinRequest
chatMember → const UpdateType
ChatMember
chosenInlineResult → const UpdateType
ChosenInlineResult
editedChannelPost → const UpdateType
EditedChannelPost
editedMessage → const UpdateType
EditedMessage
inlineQuery → const UpdateType
InlineQuery
message → const UpdateType
Message
myChatMember → const UpdateType
MyChatMember
poll → const UpdateType
Poll
pollAnswer → const UpdateType
PollAnswer
preCheckoutQuery → const UpdateType
PreCheckoutQuery
shippingQuery → const UpdateType
ShippingQuery
values → const Map<String, UpdateType>
Values