Video class

This object represents a video file.

Constructors

Video({required String fileId, required String fileUniqueId, required int width, required int height, required int duration, PhotoSize? thumb, String? fileName, String? mimeType, int? fileSize})
Basic constructor

Properties

duration ↔ int
Duration of the video in seconds as defined by sender
getter/setter pair
fileId ↔ String
Identifier for this file, which can be used to download or reuse the file
getter/setter pair
fileName ↔ String?
Optional. Original filename as defined by sender
getter/setter pair
fileSize ↔ int?
Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.
getter/setter pair
fileUniqueId ↔ String
Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
Video height as defined by sender
getter/setter pair
mimeType ↔ String?
Optional. MIME type of the file as defined by sender
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumb ↔ PhotoSize?
Optional. Video thumbnail
getter/setter pair
width ↔ int
Video width as defined by sender
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → Video
Creates a object from a json