VideoNote class

This object represents a video message (available in Telegram apps as of v.4.0).

Constructors

VideoNote({required String fileId, required String fileUniqueId, required int length, required int duration, PhotoSize? thumb, int? fileSize})
Basic constructor

Properties

duration ↔ int
Duration of the video in seconds as defined by sender
getter/setter pair
fileId ↔ String
Identifier for this file, which can be used to download or reuse the file
getter/setter pair
fileSize ↔ int?
Optional. File size in bytes
getter/setter pair
fileUniqueId ↔ String
Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length ↔ int
Video width and height (diameter of the video message) as defined by sender
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumb ↔ PhotoSize?
Optional. Video thumbnail
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Creates a json from the object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → VideoNote
Creates a object from a json